@@ -15,13 +15,12 @@
 #ifndef QOAUTH2AUTHORIZATIONCODEFLOW_P_H
 #define QOAUTH2AUTHORIZATIONCODEFLOW_P_H
 
-#ifndef QT_NO_HTTP
-
 #include <private/qabstractoauth2_p.h>
 
 #include <QtNetworkAuth/qoauthglobal.h>
 #include <QtNetworkAuth/qoauth2authorizationcodeflow.h>
 
+#include <QtCore/qpointer.h>
 #include <QtCore/qstring.h>
 #include <QtCore/qdatetime.h>
 
@@ -42,6 +41,13 @@ public:
     void _q_accessTokenRequestFailed(QAbstractOAuth::Error error, const QString &errorString = {});
     void _q_authenticate(QNetworkReply *reply, QAuthenticator *authenticator);
 
+    QByteArray createPKCEChallenge();
+
+    QOAuth2AuthorizationCodeFlow::PkceMethod pkceMethod
+        = QOAuth2AuthorizationCodeFlow::PkceMethod::S256;
+    quint8 pkceVerifierLength = 43; // RFC 7636 Section 4.1
+    QByteArray pkceCodeVerifier;
+
     QUrl accessTokenUrl;
     QString tokenType;
     QPointer<QNetworkReply> currentReply;
@@ -49,6 +55,4 @@ public:
 
 QT_END_NAMESPACE
 
-#endif // QT_NO_HTTP
-
 #endif // QOAUTH2AUTHORIZATIONCODEFLOW_P_H
